package com.vcarecity.publish.elastic.service.impl;

import com.vcarecity.publish.elastic.service.ElasticIndexService;
import com.vcarecity.publish.util.Utils;
import lombok.extern.slf4j.Slf4j;
import org.elasticsearch.action.admin.indices.delete.DeleteIndexRequest;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.client.indices.CreateIndexRequest;
import org.elasticsearch.client.indices.CreateIndexResponse;
import org.elasticsearch.client.indices.GetIndexRequest;
import org.elasticsearch.common.xcontent.XContentType;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * @author kerryzhang on 2019/12/17
 */

@Slf4j
@Service
public class ElasticIndexServiceImpl implements ElasticIndexService {

    @Value("${app.index.config}")
    private String indexConfig;

    private final RestHighLevelClient restHighLevelClient;

    public ElasticIndexServiceImpl(RestHighLevelClient restHighLevelClient) {
        this.restHighLevelClient = restHighLevelClient;
    }

    @Override
    public boolean indexExist(String index) throws IOException {
        GetIndexRequest request = new GetIndexRequest(index);
        return restHighLevelClient.indices().exists(request, RequestOptions.DEFAULT);
    }

    @Override
    public boolean createIndex(String index) throws IOException {
        CreateIndexRequest request = new CreateIndexRequest(index);
        try {
            File file = new File(indexConfig + "/" + index + ".setting.json");
            String setting = Utils.readFile(file);
            request.settings(setting, XContentType.JSON);
        } catch (IOException e) {
            logger.warn("setting file not found. usage default setting config");
        }

        try {
            File file = new File(indexConfig + "/" + index + ".mapping.json");
            String mapping = Utils.readFile(file);
            request.mapping(mapping, XContentType.JSON);
        } catch (IOException e) {
            logger.warn("mapping file not found. usage default mapping config");
        }

        CreateIndexResponse createIndexResponse = restHighLevelClient.indices().create(request, RequestOptions.DEFAULT);
        return createIndexResponse.isAcknowledged();

    }

    @Override
    public void deleteIndex(String... indices) throws IOException {
        logger.warn("delete elastic index = {}", indices);
        DeleteIndexRequest request = new DeleteIndexRequest(indices);
        restHighLevelClient.indices().delete(request, RequestOptions.DEFAULT);
    }

    @Override
    public List<String> indices() {
        return null;
    }


}
