package com.vcarecity.publish.service.impl;

import com.vcarecity.publish.constants.ElasticConstant;
import com.vcarecity.publish.service.CheckTimeService;
import com.vcarecity.publish.util.DateUtil;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;

/**
 * @author VcKerry on 12/17/19
 */

@Service
public class CheckTimeServiceImpl implements CheckTimeService {


    public static final String REDIS_KEY_PREFIX = "elastic:";

    private final RedisTemplate<String, Object> redisTemplate;


    public CheckTimeServiceImpl(RedisTemplate<String, Object> redisTemplate) {
        this.redisTemplate = redisTemplate;
    }

    @Override
    public String getLastDateTime(String key) {
        String redisKey = REDIS_KEY_PREFIX + key;

        Object value = redisTemplate.opsForValue().get(redisKey);
        long last;
        //noinspection ConstantConditions
        if (value == null) {
            last = System.currentTimeMillis() - ElasticConstant.CHECK_TIME_INTERVAL;
        } else {
            last = Long.parseLong(value.toString());
        }
        redisTemplate.opsForValue().set(redisKey, last);
        return LocalDateTime.ofInstant(new Date(last).toInstant(), ZoneId.systemDefault()).format(DateUtil.DATE_TIME_FORMATTER);
    }

    @Override
    public void setLastDateTime(String key, long lastDateTime) {
        String redisKey = REDIS_KEY_PREFIX + key;
        redisTemplate.opsForValue().set(redisKey, lastDateTime);
    }
}
